Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/tyora/__init__.py | (no class) | 0 | 0 | 0 | 100%
src/tyora/session.py | MoocfiCsesSession | 34 | 4 | 0 | 88%
src/tyora/session.py | (no class) | 21 | 2 | 0 | 90%
src/tyora/tyora.py | TaskState | 0 | 0 | 0 | 100%
src/tyora/tyora.py | Task | 0 | 0 | 0 | 100%
src/tyora/tyora.py | (no class) | 54 | 3 | 0 | 94%
tests/__init__.py | (no class) | 0 | 0 | 0 | 100%
tests/test_session.py | (no class) | 9 | 0 | 0 | 100%
tests/test_tyora.py | TestFindLink | 3 | 0 | 0 | 100%
tests/test_tyora.py | TestParseForm | 0 | 0 | 0 | 100%
tests/test_tyora.py | (no class) | 17 | 0 | 0 | 100%
Total |  | 138 | 9 | 0 | 93%

No items found using the specified filter.